import '../app_clock_service/app_clock.dart';
import '../data_service/data_service.dart';
import '../iproximitydetection/iproximitydetection.dart';

class DetectionService
{
  static final _instance = DetectionService._internal();
  factory DetectionService() => _instance;
  DetectionService._internal();

  bool _isStarted = false;
  bool get isStarted => _isStarted;

  IProximityDetection _proximityDetection;

  Future<void> start(IProximityDetection proximityDetection) async
  {
    if (_isStarted)
      return null;

    _proximityDetection = proximityDetection;
    print("HEROES_FLUTTER_PLUGIN :: DetectionService :: start()");
    _proximityDetection.onDetectedCallback = startEncounter;
    _proximityDetection.onLostCallback = endEncounter;
    await _proximityDetection.startScanning();
    _isStarted = true;
    return null;
  }

  Future<void> stop() async
  {
    if (!_isStarted)
      return null;
    
    print("HEROES_FLUTTER_PLUGIN :: DetectionService :: stop()");
    AppClock().stopIsolate();
    await _proximityDetection.stopScanning();
    _isStarted = false;
    return null;
  }

  void startEncounter(String id, DateTime timeOfEncounter)
  {
    DataService().startEncounter(id, timeOfEncounter);
  }

  void endEncounter(String id)
  {
    DataService().finishEncounter(id);
  }

  void endAllEncounters()
  {
    DataService().finishAllEncounters();
  }
}
